Learn R Programming

civis (version 1.1.0)

clusters_get_kubernetes: Describe a Kubernetes Cluster

Description

Describe a Kubernetes Cluster

Usage

clusters_get_kubernetes(id)

Arguments

id

integer required. The ID of this cluster.

Value

A list containing the following elements:

id

integer, The ID of this cluster.

instanceType

string, The EC2 instance types in this cluster.

minInstances

integer, The minimum number of instances in this cluster.

maxInstances

integer, The maximum number of instances in this cluster.

instanceMaxMemory

integer, The amount of memory available to a single instance.

instanceMaxCpu

integer, The number of processor shares available to a single instance.

organizationId

string, The id of this cluster's organization.

organizationSlug

string, The slug of this cluster's organization.

securityGroupId

string, The security group to be added to the nodes of this cluster