Learn R Programming

civis (version 1.1.0)

clusters_list_kubernetes: List Kubernetes Clusters

Description

List Kubernetes Clusters

Usage

clusters_list_kubernetes(organization_slug = NULL, limit = NULL,
  page_num = NULL, order = NULL, order_dir = NULL)

Arguments

organization_slug

string optional. The slug of this cluster's organization.

limit

integer optional. Number of results to return. Defaults to its maximum of 50.

page_num

integer optional. Page number of the results to return. Defaults to the first page, 1.

order

string optional. The field on which to order the result set. Defaults to organization_id. Must be one of: organization_id, created_at.

order_dir

string optional. Direction in which to sort, either asc (ascending) or desc (descending) defaulting to asc.

Value

An array containing the following fields:

id

integer, The ID of this cluster.

instanceType

string, The EC2 instance types in this cluster.

minInstances

integer, The minimum number of instances in this cluster.

maxInstances

integer, The maximum number of instances in this cluster.

instanceMaxMemory

integer, The amount of memory available to a single instance.

instanceMaxCpu

integer, The number of processor shares available to a single instance.

organizationId

string, The id of this cluster's organization.

organizationSlug

string, The slug of this cluster's organization.

securityGroupId

string, The security group to be added to the nodes of this cluster