Learn R Programming

civis (version 1.1.0)

clusters_list_workers_active_jobs: List Active Jobs for a Worker Cluster

Description

List Active Jobs for a Worker Cluster

Usage

clusters_list_workers_active_jobs(id)

Arguments

id

integer required. The ID of this cluster.

Value

A list containing the following elements:

id

integer,

name

string,

type

string,

state

string, Whether the job is idle, queued, running, cancelled, or failed.

createdAt

string,

updatedAt

string,

runs

array, An array containing the following fields:

  • id integer,

  • state string,

  • createdAt string, The time that the run was queued.

  • startedAt string, The time that the run started.

  • finishedAt string, The time that the run completed.

  • error string, The error message for this run, if present.

lastRun

object, A list containing the following elements:

  • id integer,

  • state string,

  • createdAt string, The time that the run was queued.

  • startedAt string, The time that the run started.

  • finishedAt string, The time that the run completed.

  • error string, The error message for this run, if present.

hidden

boolean, The hidden status of the object.

requiredCpu

integer, The CPU shares required by the script.

requiredDiskSpace

integer, The disk space in GB required by the script.

requiredMemory

integer, The memory in MB required by the script.

author

object, A list containing the following elements:

  • id integer, The ID of this user.

  • name string, This user's name.

  • username string, This user's username.

  • initials string, This user's initials.

  • online boolean, Whether this user is online.

runningAs

object, A list containing the following elements:

  • id integer, The ID of this user.

  • name string, This user's name.

  • username string, This user's username.

  • initials string, This user's initials.

  • online boolean, Whether this user is online.