enhancements_put_civis_data_match_projects: Add a Civis Data Match Enhancement to a project
Description
Add a Civis Data Match Enhancement to a project
Usage
enhancements_put_civis_data_match_projects(id, project_id)
Arguments
id
integer required. The ID of the Civis Data Match Enhancement.
project_id
integer required. The ID of the project.
Value
An empty HTTP response