Learn R Programming

civis (version 1.2.0)

files_get: Get details about a file

Description

Get details about a file

Usage

files_get(id, link_expires_at = NULL)

Arguments

id

integer required. The ID of the file object.

link_expires_at

string optional. The date and time the download link will expire. Must be a time between now and 36 hours from now. Defaults to 30 minutes from now.

Value

A list containing the following elements:

id

integer, The ID of the file object.

name

string, The file name.

createdAt

string, The date and time the file was created.

fileSize

integer, The file size.

expiresAt

string, The date and time the file will expire. If not specified, the file will expire in 30 days. To keep a file indefinitely, specify null.

downloadUrl

string, A JSON string containing information about the URL of the file.

fileUrl

string, The URL that may be used to download the file.