Learn R Programming

civis (version 1.1.0)

jobs_list_parents: Show chain of parents as a list that this job triggers from

Description

Show chain of parents as a list that this job triggers from

Usage

jobs_list_parents(id)

Arguments

id

integer required. The ID for this job.

Value

A list containing the following elements:

id

integer,

name

string,

type

string,

state

string, Whether the job is idle, queued, running, cancelled, or failed.

createdAt

string,

updatedAt

string,

runs

array, An array containing the following fields:

  • id integer,

  • state string,

  • createdAt string, The time that the run was queued.

  • startedAt string, The time that the run started.

  • finishedAt string, The time that the run completed.

  • error string, The error message for this run, if present.

lastRun

object, A list containing the following elements:

  • id integer,

  • state string,

  • createdAt string, The time that the run was queued.

  • startedAt string, The time that the run started.

  • finishedAt string, The time that the run completed.

  • error string, The error message for this run, if present.

hidden

boolean, The hidden status of the object.

archived

string, The archival status of the requested object(s).