List the workflows a job belongs to
jobs_list_workflows(id, archived = NULL)integer required.
string optional. The archival status of the requested object(s).
An array containing the following fields:
integer, The ID for this workflow.
string, The name of this workflow.
string, A description of the workflow.
boolean, The validity of the workflow definition.
string, The file id for the s3 file containing the workflow configuration.
object, A list containing the following elements:
id integer, The ID of this user.
name string, This user's name.
username string, This user's username.
initials string, This user's initials.
online boolean, Whether this user is online.
string, The state of the workflow. State is "running" if any execution is running, otherwise reflects most recent execution state.
object, A list containing the following elements:
scheduled boolean, If the object is scheduled
scheduledDays array, Day based on numeric value starting at 0 for Sunday
scheduledHours array, Hours of the day it is scheduled on
scheduledMinutes array, Minutes of the day it is scheduled on
scheduledRunsPerHour integer, Alternative to scheduled minutes, number of times to run per hour
string, The time zone of this workflow.
string, The time of the next scheduled execution.
string, The archival status of the requested object(s).
string,
string,