Learn R Programming

civis (version 1.2.0)

media_post_optimizations: Create a new optimization

Description

Create a new optimization

Usage

media_post_optimizations(runs, name = NULL)

Arguments

runs

array required. An array containing the following fields:

  • marketId integer, The market ID.

  • startDate string, The start date for the media run.

  • endDate string, The end date for the media run.

  • syscodes array, The syscodes for the media run.

  • rateCards array, The ratecards for the media run.

  • constraints array, The constraints for the media run.

name

string optional. The name of the optimization.

Value

A list containing the following elements:

id

integer, The optimization ID.

author

object, A list containing the following elements:

  • id integer, The ID of this user.

  • name string, This user's name.

  • username string, This user's username.

  • initials string, This user's initials.

  • online boolean, Whether this user is online.

name

string, The name of the optimization.

createdAt

string,

updatedAt

string,

finishedAt

string, The end time of the last run.

state

string, The state of the last run.

lastRunId

integer, The ID of the last run.

spotOrderId

integer, The ID for the spot order produced by the optimization.

archived

string, The archival status of the requested object(s).

reportLink

string, A link to the visual report for the optimization.

spotOrderLink

string, A link to the json version of the spot order.

fileLinks

array, Links to the csv and xml versions of the spot order.

runs

array, An array containing the following fields:

  • marketId integer, The market ID.

  • startDate string, The start date for the media run.

  • endDate string, The end date for the media run.

  • syscodes array, The syscodes for the media run.

  • rateCards array, The ratecards for the media run.

  • constraints array, The constraints for the media run.