Show the model build schedule
models_list_schedules(id)integer required. The ID of the model associated with this schedule.
A list containing the following elements:
integer, The ID of the model associated with this schedule.
object, A list containing the following elements:
scheduled boolean, If the object is scheduled
scheduledDays array, Day based on numeric value starting at 0 for Sunday
scheduledHours array, Hours of the day it is scheduled on
scheduledMinutes array, Minutes of the day it is scheduled on
scheduledRunsPerHour integer, Alternative to scheduled minutes, number of times to run per hour