Add a table on which to apply the predictive model
models_put_predictions(id, table_name, primary_key, limiting_sql = NULL,
output_table = NULL, schedule = NULL)integer required. The ID of the model to which to apply the prediction.
string required. The qualified name of the table on which to apply the predictive model.
array required. The primary key or composite keys of the table being predicted.
string optional. A SQL WHERE clause used to scope the rows to be predicted.
string optional. The qualified name of the table to be created which will contain the model's predictions.
object optional. A list containing the following elements:
scheduled boolean, If the object is scheduled
scheduledDays array, Day based on numeric value starting at 0 for Sunday
scheduledHours array, Hours of the day it is scheduled on
scheduledMinutes array, Minutes of the day it is scheduled on
scheduledRunsPerHour integer, Alternative to scheduled minutes, number of times to run per hour
A list containing the following elements:
integer, The ID of the model to which to apply the prediction.
string, The qualified name of the table on which to apply the predictive model.
array, The primary key or composite keys of the table being predicted.
string, A SQL WHERE clause used to scope the rows to be predicted.
string, The qualified name of the table to be created which will contain the model's predictions.
object, A list containing the following elements:
scheduled boolean, If the object is scheduled
scheduledDays array, Day based on numeric value starting at 0 for Sunday
scheduledHours array, Hours of the day it is scheduled on
scheduledMinutes array, Minutes of the day it is scheduled on
scheduledRunsPerHour integer, Alternative to scheduled minutes, number of times to run per hour
string, The status of the prediction. One of: "succeeded", "failed", "queued", or "running,"or "idle", if no build has been attempted.