Learn R Programming

civis (version 1.2.0)

models_put_schedules: Schedule the model build

Description

Schedule the model build

Usage

models_put_schedules(id, schedule)

Arguments

id

integer required. The ID of the model associated with this schedule.

schedule

object required. A list containing the following elements:

  • scheduled boolean, If the object is scheduled

  • scheduledDays array, Day based on numeric value starting at 0 for Sunday

  • scheduledHours array, Hours of the day it is scheduled on

  • scheduledMinutes array, Minutes of the day it is scheduled on

  • scheduledRunsPerHour integer, Alternative to scheduled minutes, number of times to run per hour

Value

A list containing the following elements:

id

integer, The ID of the model associated with this schedule.

schedule

object, A list containing the following elements:

  • scheduled boolean, If the object is scheduled

  • scheduledDays array, Day based on numeric value starting at 0 for Sunday

  • scheduledHours array, Hours of the day it is scheduled on

  • scheduledMinutes array, Minutes of the day it is scheduled on

  • scheduledRunsPerHour integer, Alternative to scheduled minutes, number of times to run per hour