Deploy a Notebook
notebooks_post_deployments(notebook_id, deployment_id = NULL,
published = NULL)integer required. The ID of the owning Notebook
integer optional. The ID for this deployment
boolean optional.
A list containing the following elements:
integer, The ID for this deployment.
integer, The ID of the owner.
string, Domain of the deployment.
string, Name of the deployment.
string, The name of the docker image to pull from DockerHub.
string, The tag of the docker image to pull from DockerHub (default: latest).
string, URL that displays the deployed platform object and includes auth token.
integer, The memory allocated to the deployment.
integer, The cpu allocated to the deployment.
string, The state of the deployment.
string, A detailed description of the state.
string,
string,
boolean,
integer, The ID of owning Notebook