Learn R Programming

civis (version 1.2.0)

predictions_put_schedules: Schedule the prediction

Description

Schedule the prediction

Usage

predictions_put_schedules(id, schedule = NULL, score_on_model_build = NULL)

Arguments

id

integer required. ID of the prediction associated with this schedule.

schedule

object optional. A list containing the following elements:

  • scheduled boolean, If the object is scheduled

  • scheduledDays array, Day based on numeric value starting at 0 for Sunday

  • scheduledHours array, Hours of the day it is scheduled on

  • scheduledMinutes array, Minutes of the day it is scheduled on

  • scheduledRunsPerHour integer, Alternative to scheduled minutes, number of times to run per hour

score_on_model_build

boolean optional. Whether the prediction will run after a rebuild of the associated model.

Value

A list containing the following elements:

id

integer, ID of the prediction associated with this schedule.

schedule

object, A list containing the following elements:

  • scheduled boolean, If the object is scheduled

  • scheduledDays array, Day based on numeric value starting at 0 for Sunday

  • scheduledHours array, Hours of the day it is scheduled on

  • scheduledMinutes array, Minutes of the day it is scheduled on

  • scheduledRunsPerHour integer, Alternative to scheduled minutes, number of times to run per hour

scoreOnModelBuild

boolean, Whether the prediction will run after a rebuild of the associated model.