Get details about the report's snapshot automation settings
reports_list_snapshots(id)integer required. The ID of this report.
A list containing the following elements:
integer, The ID of this report.
string, The status of the job's last run.
string, The time that the job's last run finished.
boolean, Whether the job will send emails on completion.
string, Custom email template.
string, Email addresses to send report to, comma separated.
string, Subject for Email.
integer, The height of the cropped snapshot image in screen pixels. The default value is 900 pixels. Minimum value is 600 pixels.
integer, The width of the cropped snapshot image in screen pixels. The default value is 1440 pixels. Minimum value is 600 pixels.
object, A list containing the following elements:
scheduled boolean, If the object is scheduled
scheduledDays array, Day based on numeric value starting at 0 for Sunday
scheduledHours array, Hours of the day it is scheduled on
scheduledMinutes array, Minutes of the day it is scheduled on
scheduledRunsPerHour integer, Alternative to scheduled minutes, number of times to run per hour
integer, The ID of the parent job that will trigger this snapshot.