Learn R Programming

civis (version 1.2.0)

scripts_post_python3_runs_outputs: Add an output for a run

Description

Add an output for a run

Usage

scripts_post_python3_runs_outputs(id, run_id, object_type, object_id)

Arguments

id

integer required. The ID of the python script.

run_id

integer required. The ID of the run.

object_type

string required. The type of the output. Valid values are File, Table, Report, Project, or Credential

object_id

integer required. The ID of the output object.

Value

A list containing the following elements:

objectType

string, The type of the output. Valid values are File, Table, Report, Project, or Credential

objectId

integer, The ID of the output object.

name

string, The name of the output object.

link

string, The link to retrieve the output object.