Add an output for a run
scripts_post_r_runs_outputs(id, run_id, object_type, object_id)integer required. The ID of the r script.
integer required. The ID of the run.
string required. The type of the output. Valid values are File, Table, Report, Project, or Credential
integer required. The ID of the output object.
A list containing the following elements:
string, The type of the output. Valid values are File, Table, Report, Project, or Credential
integer, The ID of the output object.
string, The name of the output object.
string, The link to retrieve the output object.