studios_get: Get a Studio

View source: R/generated_client.R

studios_getR Documentation

Get a Studio

Description

Get a Studio

Usage

studios_get(id)

Arguments

id

integer required.

Value

A list containing the following elements:

id

integer, The ID of the studio.

author

list, A list containing the following elements:

  • id integer, The ID of this user.

  • name string, This user's name.

  • username string, This user's username.

  • initials string, This user's initials.

  • online boolean, Whether this user is online.

name

string, The name of the studio.

dockerImageName

string, The name of the docker image to pull from DockerHub.

dockerImageTag

string, The tag of the docker image to pull from DockerHub (default: latest).

instanceType

string, The EC2 instance type to deploy to.

requiredResources

list, A list containing the following elements:

  • memory integer, The amount of memory allocated to the studio.

  • diskSpace number, The amount of disk space, in GB, to allocate for the studio. Fractional values (e.g. 0.25) are supported.

  • cpu integer, The amount of cpu allocated to the studio.

createdAt

string,

updatedAt

string,

mostRecentDeployment

list, A list containing the following elements:

  • deploymentId integer, The ID for this deployment.

  • userId integer, The ID of the owner.

  • host string, Domain of the deployment.

  • name string, Name of the deployment.

  • dockerImageName string, The name of the docker image to pull from DockerHub.

  • dockerImageTag string, The tag of the docker image to pull from DockerHub (default: latest).

  • displayUrl string, A signed URL for viewing the deployed item.

  • instanceType string, The EC2 instance type requested for the deployment.

  • memory integer, The memory allocated to the deployment, in MB.

  • cpu integer, The cpu allocated to the deployment, in millicores.

  • state string, The state of the deployment.

  • stateMessage string, A detailed description of the state.

  • maxMemoryUsage number, If the deployment has finished, the maximum amount of memory used during the deployment, in MB.

  • maxCpuUsage number, If the deployment has finished, the maximum amount of cpu used during the deployment, in millicores.

  • createdAt string,

  • updatedAt string,

  • studioId integer, The ID of the owning Studio

gitCredentialId

integer, The id of the git credential to be used when checking out the specified git repo. If not supplied, the first git credential you've submitted will be used.

params

array, An array containing the following fields:

  • name string, The variable's name as used within your code.

  • description string, A short sentence or fragment describing this parameter.

  • type string, The type of parameter. Valid options: string, multi_line_string, integer, float, bool, file, table, database, credential_aws, credential_redshift, or credential_custom

  • value string, The value you would like to set this param to.

gitRepoId

integer, The ID of the git repository.

gitRepoUrl

string, The URL of the git repository (e.g., https://github.com/organization/repo_name.git).

gitRef

string, The git reference if git repo is specified

partitionLabel

string, The partition label used to run this object.

myPermissionLevel

string, Your permission level on the object. One of "read", "write", or "manage".

archived

string, The archival status of the requested item(s).


civis documentation built on March 28, 2026, 1:06 a.m.