List Workflows
workflows_list(hidden = NULL, archived = NULL, author = NULL,
limit = NULL, page_num = NULL, order = NULL, order_dir = NULL)boolean optional. If specified to be true, returns hidden objects. Defaults to false, returning non-hidden objects.
string optional. The archival status of the requested object(s).
string optional. If specified, return workflows from this author. It accepts a comma-separated list of author ids.
integer optional. Number of results to return. Defaults to 20. Maximum allowed is 50.
integer optional. Page number of the results to return. Defaults to the first page, 1.
string optional. The field on which to order the result set. Defaults to updated_at. Must be one of: updated_at, name, created_at.
string optional. Direction in which to sort, either asc (ascending) or desc (descending) defaulting to desc.
An array containing the following fields:
integer, The ID for this workflow.
string, The name of this workflow.
boolean, The validity of the workflow definition.
string, The file id for the s3 file containing the workflow configuration.
object, A list containing the following elements:
id integer, The ID of this user.
name string, This user's name.
username string, This user's username.
initials string, This user's initials.
online boolean, Whether this user is online.
string, The state of the workflow. State is "running" if any execution is running, otherwise reflects most recent execution state.
string, The time zone of this workflow.
string, The time of the next scheduled execution.
string, The archival status of the requested object(s).
string,
string,