Learn R Programming

civis (version 1.2.0)

workflows_post_executions_cancel: Cancel a workflow execution

Description

Cancel a workflow execution

Usage

workflows_post_executions_cancel(id, execution_id)

Arguments

id

integer required. The ID for the workflow.

execution_id

integer required. The ID for the workflow execution.

Value

A list containing the following elements:

id

integer, The ID for this workflow execution.

state

string, The state of this workflow execution.

mistralState

string, The state of this workflow as reported by mistral. One of running, paused, success, error, or cancelled

mistralStateInfo

string, The state info of this workflow as reported by mistral.

user

object, A list containing the following elements:

  • id integer, The ID of this user.

  • name string, This user's name.

  • username string, This user's username.

  • initials string, This user's initials.

  • online boolean, Whether this user is online.

definition

string, The definition of the workflow for this execution.

input

object, The dictionary of name/value input pairs defined for this execution.

tasks

array, An array containing the following fields:

  • name string, The name of the task.

  • mistralState string, The state of this task. One of idle, waiting, running, delayed, success, or error

  • mistralStateInfo string, Extra info associated with the state of the task.

  • runs array, The runs associated with this task, in descending order by id.

startedAt

string, The time this execution started.

finishedAt

string, The time this execution finished.

createdAt

string, The time this execution was created.

updatedAt

string, The time this execution was last updated.