write_chunks: Split a file into chunks of a given chunk size, returning a...

View source: R/io.R

write_chunksR Documentation

Split a file into chunks of a given chunk size, returning a list of file names.

Description

Split a file into chunks of a given chunk size, returning a list of file names.

Usage

write_chunks(file, chunk_size)

Arguments

file

name of the file

chunk_size

size of the chunk in bytes.


civis documentation built on March 28, 2026, 1:06 a.m.