Evaluate an expression in Civis Platform
CivisFuture(expr = NULL, envir = parent.frame(), substitute = FALSE,
globals = TRUE, packages = NULL, lazy = FALSE, local = TRUE,
gc = FALSE, earlySignal = FALSE, label = NULL,
required_resources = list(cpu = 1024, memory = 2048, diskSpace = 4),
docker_image_name = "civisanalytics/datascience-r",
docker_image_tag = "2.3.0", ...)An R expression.
The environment in which the evaluation
is done (or inherits from if local is TRUE).
If TRUE, argument expr is
substitute():ed, otherwise not.
(optional) a named list of global objects needed in order for the future to be resolved correctly.
(optional) a character vector specifying packages to be attached in the R environment evaluating the future.
If FALSE (default), the future is resolved
eagerly (starting immediately), otherwise not.
If TRUE, the expression is evaluated such that all assignments are done to local temporary environment, otherwise the assignments are done to the global environment of the R process evaluating the future.
If TRUE, the garbage collector run (in the process that evaluated the future) after the value of the future is collected. Some types of futures ignore this argument.
Specified whether conditions should be signaled as soon as possible or not.
An optional character string label attached to the future.
resources, see scripts_post_containers
the image for the container script.
the tag for the Docker image.
arguments to scripts_post_containers
A CivisFuture inheriting from Future that evaluates expr on the given container.