Describe a Kubernetes Cluster
clusters_get_kubernetes(id)integer required. The ID of this cluster.
A list containing the following elements:
integer, The ID of this cluster.
string, The EC2 instance types in this cluster.
integer, The minimum number of instances in this cluster.
integer, The maximum number of instances in this cluster.
integer, The amount of memory available to a single instance.
integer, The number of processor shares available to a single instance.
string, The id of this cluster's organization.
string, The slug of this cluster's organization.
string, The security group to be added to the nodes of this cluster