List Kubernetes Clusters
clusters_list_kubernetes(organization_slug = NULL, limit = NULL,
page_num = NULL, order = NULL, order_dir = NULL)string optional. The slug of this cluster's organization.
integer optional. Number of results to return. Defaults to its maximum of 50.
integer optional. Page number of the results to return. Defaults to the first page, 1.
string optional. The field on which to order the result set. Defaults to organization_id. Must be one of: organization_id, created_at.
string optional. Direction in which to sort, either asc (ascending) or desc (descending) defaulting to asc.
An array containing the following fields:
integer, The ID of this cluster.
string, The EC2 instance types in this cluster.
integer, The minimum number of instances in this cluster.
integer, The maximum number of instances in this cluster.
integer, The amount of memory available to a single instance.
integer, The number of processor shares available to a single instance.
string, The id of this cluster's organization.
string, The slug of this cluster's organization.
string, The security group to be added to the nodes of this cluster