Get details about a file
files_get(id, link_expires_at = NULL)integer required. The ID of the file object.
string optional. The date and time the download link will expire. Must be a time between now and 36 hours from now. Defaults to 30 minutes from now.
A list containing the following elements:
integer, The ID of the file object.
string, The file name.
string, The date and time the file was created.
integer, The file size.
string, The date and time the file will expire. If not specified, the file will expire in 30 days. To keep a file indefinitely, specify null.
string, A JSON string containing information about the URL of the file.
string, The URL that may be used to download the file.