Show chain of parents as a list that this job triggers from
jobs_list_parents(id)integer required. The ID for this job.
A list containing the following elements:
integer,
string,
string,
string, Whether the job is idle, queued, running, cancelled, or failed.
string,
string,
array, An array containing the following fields:
id integer,
state string,
createdAt string, The time that the run was queued.
startedAt string, The time that the run started.
finishedAt string, The time that the run completed.
error string, The error message for this run, if present.
object, A list containing the following elements:
id integer,
state string,
createdAt string, The time that the run was queued.
startedAt string, The time that the run started.
finishedAt string, The time that the run completed.
error string, The error message for this run, if present.
boolean, The hidden status of the object.
string, The archival status of the requested object(s).