Create a new optimization
media_post_optimizations(runs, name = NULL)array required. An array containing the following fields:
marketId integer, The market ID.
startDate string, The start date for the media run.
endDate string, The end date for the media run.
syscodes array, The syscodes for the media run.
rateCards array, The ratecards for the media run.
constraints array, The constraints for the media run.
string optional. The name of the optimization.
A list containing the following elements:
integer, The optimization ID.
object, A list containing the following elements:
id integer, The ID of this user.
name string, This user's name.
username string, This user's username.
initials string, This user's initials.
online boolean, Whether this user is online.
string, The name of the optimization.
string,
string,
string, The end time of the last run.
string, The state of the last run.
integer, The ID of the last run.
integer, The ID for the spot order produced by the optimization.
string, The archival status of the requested object(s).
string, A link to the visual report for the optimization.
string, A link to the json version of the spot order.
array, Links to the csv and xml versions of the spot order.
array, An array containing the following fields:
marketId integer, The market ID.
startDate string, The start date for the media run.
endDate string, The end date for the media run.
syscodes array, The syscodes for the media run.
rateCards array, The ratecards for the media run.
constraints array, The constraints for the media run.