Update the archive status of this object
notebooks_put_archive(id, status)integer required. The ID of the object.
boolean required. The desired archived status of the object.
A list containing the following elements:
integer, The ID for this notebook.
string, The name of this notebook.
string, The kernel language of this notebook.
string, The description of this notebook.
string, Time-limited URL to get the .ipynb file for this notebook.
string, Time-limited URL to get the .htm preview file for this notebook.
string, Time-limited URL to get the requirements.txt file for this notebook.
string, The file ID for the S3 file containing the .ipynb file.
string, The file ID for the S3 file containing the requirements.txt file.
object, A list containing the following elements:
id integer, The ID of this user.
name string, This user's name.
username string, This user's username.
initials string, This user's initials.
online boolean, Whether this user is online.
string, The name of the docker image to pull from DockerHub.
string, The tag of the docker image to pull from DockerHub (default: latest).
integer, The amount of memory allocated to the notebook.
integer, The amount of cpu allocated to the the notebook.
string,
string,
object, A list containing the following elements:
deploymentId integer, The ID for this deployment.
userId integer, The ID of the owner.
host string, Domain of the deployment.
name string, Name of the deployment.
dockerImageName string, The name of the docker image to pull from DockerHub.
dockerImageTag string, The tag of the docker image to pull from DockerHub (default: latest).
displayUrl string, URL that displays the deployed platform object and includes auth token.
memory integer, The memory allocated to the deployment.
cpu integer, The cpu allocated to the deployment.
state string, The state of the deployment.
stateMessage string, A detailed description of the state.
createdAt string,
updatedAt string,
published boolean,
notebookId integer, The ID of owning Notebook
array, A list of credential IDs to pass to the notebook.
string, The URL of the repository that will be cloned.
string, The name of the branch that will be cloned.
string, The name of the notebook file within a repository that will be included in the deployment.
object, Environment variables to be passed into the Notebook.
integer, How long the notebook will stay alive without any kernel activity.
string, The archival status of the requested object(s).
boolean, The hidden status of the object.