View source: R/generated_client.R
| studios_get | R Documentation |
Get a Studio
studios_get(id)
id |
integer required. |
A list containing the following elements:
id |
integer, The ID of the studio. |
author |
list, A list containing the following elements:
|
name |
string, The name of the studio. |
dockerImageName |
string, The name of the docker image to pull from DockerHub. |
dockerImageTag |
string, The tag of the docker image to pull from DockerHub (default: latest). |
instanceType |
string, The EC2 instance type to deploy to. |
requiredResources |
list, A list containing the following elements:
|
createdAt |
string, |
updatedAt |
string, |
mostRecentDeployment |
list, A list containing the following elements:
|
gitCredentialId |
integer, The id of the git credential to be used when checking out the specified git repo. If not supplied, the first git credential you've submitted will be used. |
params |
array, An array containing the following fields:
|
gitRepoId |
integer, The ID of the git repository. |
gitRepoUrl |
string, The URL of the git repository (e.g., https://github.com/organization/repo_name.git). |
gitRef |
string, The git reference if git repo is specified |
partitionLabel |
string, The partition label used to run this object. |
myPermissionLevel |
string, Your permission level on the object. One of "read", "write", or "manage". |
archived |
string, The archival status of the requested item(s). |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.